# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v3.17.0~c9c36f0',
    built_at='2022-11-01 09:13:03Z',
    sha='c9c36f0ca804ac916b8b7463c2aca9c32b3ca075',
    branch='HEAD',
    tag='v3.17.0',
)
